# Generated by roxygen2: do not edit by hand

S3method(print,bibnets_network)
S3method(summary,bibnets_network)
export(author_network)
export(backbone)
export(conetwork)
export(country_network)
export(document_network)
export(filter_top)
export(historiograph)
export(institution_network)
export(keyword_network)
export(local_citations)
export(normalize)
export(prune)
export(read_biblio)
export(read_bibtex)
export(read_crossref)
export(read_dimensions)
export(read_lens)
export(read_openalex)
export(read_openalex_csv)
export(read_ris)
export(read_scopus)
export(read_wos)
export(reference_network)
export(source_network)
export(split_field)
export(temporal_network)
export(to_cograph)
export(to_gephi)
export(to_graphml)
export(to_igraph)
export(to_matrix)
export(to_tbl_graph)
importFrom(utils,head)
