% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/converters.R
\name{to_igraph}
\alias{to_igraph}
\title{Convert edge data frame to igraph}
\usage{
to_igraph(edges, directed = FALSE)
}
\arguments{
\item{edges}{A data frame with at least \code{from}, \code{to}, \code{weight} columns,
as returned by any network function in bibnets.}

\item{directed}{Logical. Default \code{FALSE}.}
}
\value{
An igraph graph object.
}
\description{
Convert edge data frame to igraph
}
\examples{
\dontshow{if (requireNamespace("igraph", quietly = TRUE)) withAutoprint(\{ # examplesIf}
data(biblio_data)
edges <- author_network(biblio_data, "collaboration")
g <- to_igraph(edges)
\dontshow{\}) # examplesIf}
}
